@@ -192,7 +192,7 @@ def html_render(*args, **kwargs):
     g = pyll.app_globals._current_obj()
     session = pyll.session._current_obj()
     c = pyll.tmpl_context._current_obj()
-    globals.update(c=c)
+    #globals.update(c=c)
 
     if args:
         assert len(args) == 1,\
